ReflectionUtil (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j.reflection

## Class ReflectionUtil

- java.lang.Object
- - py4j.reflection.ReflectionUtil

-     public class ReflectionUtil
      extends java.lang.Object

  Global utility to load classes and perform general reflection operations that can be customized by Strategy classes.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `ReflectionUtil()`

  - ### Method Summary

    All Methods Static Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `static java.lang.Class<?>` | `classForName(java.lang.String className)`
    `static ClassLoadingStrategy` | `getClassLoadingStrategy()`
    `static void` | `setClassLoadingStrategy(ClassLoadingStrategy classLoadingStrategy)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### ReflectionUtil

          public ReflectionUtil()

  - ### Method Detail

    - #### getClassLoadingStrategy

          public static ClassLoadingStrategy getClassLoadingStrategy()

    - #### setClassLoadingStrategy

          public static void setClassLoadingStrategy(ClassLoadingStrategy classLoadingStrategy)

    - #### classForName

          public static java.lang.Class<?> classForName(java.lang.String className)
                                                 throws java.lang.ClassNotFoundException

      Throws:
        `java.lang.ClassNotFoundException`